/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.launcher;

import java.io.File;
import java.io.FilenameFilter;
import java.net.URL;
import java.net.URLClassLoader;

import org.ow2.petals.launcher.configuration.Configuration;
import org.ow2.petals.launcher.exception.PetalsLauncherException;

/**
 * A class loader that looks first in the kernels jar to avoid java.lang.LinkageError with JAXB API.
 * @author Sebastien Andre - EBM WebSourcing
 */
public class PetalsClassLoader extends URLClassLoader {

    protected final static String PETALS_KERNEL_JAR_REGEXP = "petals-microkernel-(\\d+)(\\.(\\d+))?(\\.(\\d+))?(-.*)?\\.jar";

    public PetalsClassLoader(Configuration config) throws PetalsLauncherException {
        super(new URL[] {}, PetalsClassLoader.class.getClassLoader());

        try {
            // Add the kenel JAR to the classloader
            FilenameFilter filter = new FilenameFilter() {
                @Override
                public boolean accept(File dir, String name) {
                    return name.matches(PETALS_KERNEL_JAR_REGEXP);
                }
            };

            for (File jar : config.getLibDirectory().listFiles(filter)) {
                super.addURL(jar.toURI().toURL());
            }

            // Add the microkernel extensions to the classloader
            final File extDir = config.getExtensionsDirectory();
            if (extDir != null) {
                if (extDir.exists()) {
                    if (extDir.isDirectory()) {
                        for (File jar : extDir.listFiles()) {
                            super.addURL(jar.toURI().toURL());
                        }
                    } else {
                        throw new PetalsLauncherException("The provided extension directory '"
                                + extDir + "' is not a directory.");
                    }
                }
            }
        } catch (Exception e) {
            throw new PetalsLauncherException(e);
        }

    }
}
